#!/bin/bash
########################################################################

# hosts to push
hosts=(
    'rsync.tier2.fr-sbg1.burble.dn42'
)

########################################################################

# where am I ?
SCRIPTPATH="$(cd "$(dirname "$0")" ; pwd -P)"
pushd "$SCRIPTPATH"

function cleanup {
    local tmp="${SCRIPTPATH}/.tmp"
    if [ -d "$tmp" ]
    then
        rm -rf "$tmp" > /dev/null 2>&1
    fi
}
trap cleanup EXIT

export VAULT_ADDR='https://vault.burble.dn42'
if [ "$(id -un)" = 'drone' ]
then
    export HOME=/drone
fi

########################################################################
# generate one time key for deployment access

echo "Generating temporary user key"
mkdir -m 0700 .tmp

key='.tmp/rsync_key'
ssh-keygen -t ed25519 -a 100 -N '' -f "$key"

vault write \
      -field=signed_key \
      burble.dn42/ssh/user/sign/rsync \
      public_key="@${key}.pub" \
      > "${key}-cert.pub"
# fixup perms
chmod 0600 .tmp/*

########################################################################

for host in ${hosts[@]}
do
    echo "Syncing host: $host"
    rsync -avogp --delete -e "ssh -i '${key}'" \
          --chown 100:101 --chmod=D2750,F640 \
          pages/ "root@${host}:apps/php-apps/burble.dn42/user/pages/"
done


popd
########################################################################
# end of file
